/*
 *  FSPluginElement.h
 *  FStream
 *
 *  Created by Julien-Pierre Avérous on 12/05/07.
 *  Copyright 2007 SourceMac. All rights reserved.
 *
 */

#import <Cocoa/Cocoa.h>
#import "FSPluginConstant.h"

@protocol FSPluginElement <NSObject>

	// Call when the plug-in is loaded in memory
	- (void)installPlugin:(NSBundle*)bundle;
	
	// Called when FStream will unload the plug-in
	- (void)uninstallPlugin;
	
	
	
	// Name of your plug-in
	- (NSString *)name;
	
	// Author of your plug-in
	- (NSString *)author;
	
	// Version of your plug-in
	- (NSString *)version;
	
	// A short description of your plug-in
	- (NSString *)description;
	
	// A web site URL where the user can find this plug-in or informations about you
	- (NSURL *)URL;
	
	// An image who show a preview of your skin
	- (NSImage *)image;
	
	// An unique identifiant that identify your plug-in
	- (NSString*)identifiant;



	// Should return the interface image identified by "imageID"
	- (NSImage*)imageWithID:(FSPluginImage)imageID;
	
	// Should return the position of the interface element identified by "elementID"
	- (NSPoint)positionWithID:(FSPluginElement)elementID;
	
	// Should return the size of the interface element identified by "elementID"
	- (NSSize)sizeWithID:(FSPluginElement)elementID;
	
	// Should return a standard Cocoa NSString style identified by "styleID"
	- (NSDictionary*)styleWithID:(FSPluginStyle)styleID;
	
	// Should return if a prefix of the text area should be printed or not
	- (BOOL)hiddenPrefix:(FSPluginPrefix)prefixID;
	
	
	
	// Called by FStream to inform your plug-in of the recording stat
	- (void)setRecording:(BOOL)recording;
	
	// Called by FStream to inform your plug-in of the buffer stat
	- (void)setBufferPercent:(int)p100;
	
	// Called by FStream when the user change the showed panel.
	- (void)setPanel:(FSPluginPanel)panelID;
	
	
	
	// Call by FStream to know if the mouse is on a element (identified by "elementID") of your skin, or not
	- (BOOL)mouseOn:(FSPluginElement)elementID withPosition:(NSPoint)point;
	
	
	// Call periodically by FStream if you wan't to animate your skin. Should return YES if you wan't to refresh the element, NO else
	- (BOOL)runner:(FSPluginRunnerAction)runnerActionID forElement:(FSPluginElement)elementID;
@end
