//
//  SampleClass.m
//  Sample
//
//  Created by Julien-Pierre Avérous on 12/05/07.
//  Copyright 2007 SourceMac. All rights reserved.
//

#import "FSPluginConstant.h"
#import "FSPluginElement.h"


// Delta for the shadow
#define dx 15
#define dy 20


// Interface
@interface SampleClass : NSObject <FSPluginElement>
{
	NSMutableDictionary	*pics;
	NSBundle			*myself;
	
	int					anim;
	BOOL				animStat;
}

- (NSImage*)imageNamed:(NSString*)name;
@end



@implementation SampleClass

/* To make things more simple */
- (NSImage*)imageNamed:(NSString*)name
{
	NSString *path = [myself pathForResource:name ofType:nil];
	return [[[NSImage alloc] initWithContentsOfFile:path] autorelease];
}

/*
** Our plug-in is loaded in memory, with a NSBundle instance representative of ourself
** You can initiate your data here, by example.
*/
- (void)installPlugin:(NSBundle*)bundle
{
	pics = [[NSMutableDictionary alloc] initWithCapacity:10];
	myself = [bundle retain];
	anim = 0;
	animStat = NO;

	[pics setObject:[self imageNamed:@"backr.png"] forKey:[NSNumber numberWithInt:kImageBackRecordPanel]];
	[pics setObject:[self imageNamed:@"back.png"] forKey:[NSNumber numberWithInt:kImageBackPlayPanel]];
	
	
	[pics setObject:[self imageNamed:@"volume.png"] forKey:[NSNumber numberWithInt:kImageVolumeOn]];
	[pics setObject:[self imageNamed:@"volume.png"] forKey:[NSNumber numberWithInt:kImageVolumeOff]];
	[pics setObject:[self imageNamed:@"volume.png"] forKey:[NSNumber numberWithInt:kImageVolumeDown]];
	
	[pics setObject:[self imageNamed:@"pop.png"] forKey:[NSNumber numberWithInt:kImagePopupOn]];
	[pics setObject:[self imageNamed:@"pop.png"] forKey:[NSNumber numberWithInt:kImagePopupOff]];
	[pics setObject:[self imageNamed:@"pop.png"] forKey:[NSNumber numberWithInt:kImagePopupDown]];
	
	
	[pics setObject:[self imageNamed:@"play.png"] forKey:[NSNumber numberWithInt:kImagePlayOn]];
	[pics setObject:[self imageNamed:@"play.png"] forKey:[NSNumber numberWithInt:kImagePlayOff]];
	[pics setObject:[self imageNamed:@"playo.png"] forKey:[NSNumber numberWithInt:kImagePlayDown]];
	
	[pics setObject:[self imageNamed:@"pause.png"] forKey:[NSNumber numberWithInt:kImagePauseOn]];
	[pics setObject:[self imageNamed:@"pause.png"] forKey:[NSNumber numberWithInt:kImagePauseOff]];
	[pics setObject:[self imageNamed:@"pauseo.png"] forKey:[NSNumber numberWithInt:kImagePauseDown]];
	
	[pics setObject:[self imageNamed:@"stop.png"] forKey:[NSNumber numberWithInt:kImageStopOn]];
	[pics setObject:[self imageNamed:@"stop.png"] forKey:[NSNumber numberWithInt:kImageStopOff]];
	[pics setObject:[self imageNamed:@"stopo.png"] forKey:[NSNumber numberWithInt:kImageStopDown]];
	
	[pics setObject:[self imageNamed:@"record.png"] forKey:[NSNumber numberWithInt:kImageRecordOn]];
	[pics setObject:[self imageNamed:@"record.png"] forKey:[NSNumber numberWithInt:kImageRecordOff]];
	[pics setObject:[self imageNamed:@"recordo.png"] forKey:[NSNumber numberWithInt:kImageRecordDown]];
	
	[pics setObject:[self imageNamed:@"reload.png"] forKey:[NSNumber numberWithInt:kImageReloadOn]];
	[pics setObject:[self imageNamed:@"reload.png"] forKey:[NSNumber numberWithInt:kImageReloadOff]];
	[pics setObject:[self imageNamed:@"reloado.png"] forKey:[NSNumber numberWithInt:kImageReloadDown]];
}

/*
** Our plug-in is unloaded from memory.
** You can liberate your variable here, by example.
*/
- (void)uninstallPlugin
{
	[pics release];
	[myself release];
}

/*
** Should return a NSString containing the author name of the plug-in
*/
- (NSString *)author
{
	return @"Averous Julien-Pierre";
}

/*
** Should return a NSString containing the plug-in name
*/
- (NSString *)name
{
	return @"Sample Plug-In";
}

/*
** Should return a NSString containing the plug-in version
*/
- (NSString *)version
{
	return @"1.4.2";
}

/*
** Should return a NSString containing the plug-in description
*/
- (NSString *)description
{
	return @"Simple sample";
}

/*
** Should return a NSString containing a web link for a page containing more information about the plug-in
*/
- (NSURL *)URL
{
	return [NSURL URLWithString:@"http://www.sourcemac.com"];
}

/*
** Should return a NSImage containing a preview of the plug-in
*/
- (NSImage *)image
{
	return [self imageNamed:@"prew.png"];
}

/*
** Should return a NSString containing an unique ID to designate this plug-in
*/
- (NSString*)identifiant
{
	return @"SmplPlug";
}

/*
** Should return an NSImage containing the visual representation of a part of the interface (identified by imageID)
*/
- (NSImage*)imageWithID:(FSPluginImage)imageID
{
	switch(imageID)
	{
		case kImageLoadingDown:
		case kImageLoadingOff:
		case kImageLoadingOn:
			if (animStat)
				return [pics objectForKey:[NSNumber numberWithInt:kImagePlayOn]];
			else
				return [pics objectForKey:[NSNumber numberWithInt:kImagePlayDown]];
		
		default:
			return [pics objectForKey:[NSNumber numberWithInt:imageID]];
	}
}

/*
** Should return an NSPoint containing the coordinate of a part of the interface (identified by elementID)
*/
- (NSPoint)positionWithID:(FSPluginElement)elementID
{
	switch (elementID)
	{
		case kElementBack:
			return NSMakePoint(dx, dy);
			
		case kElementControler:
			return NSMakePoint(21 + dx, 50 + dy);
			
		case kElementPopup:
			return NSMakePoint(1 + dx, 41 + dy);
			
		case kElementVolume:
			return NSMakePoint(1 + dx, 82 + dy);
			
		case kElementText:
			return NSMakePoint(8 + dx, 7 + dy);
			
		case kElementPercent:
			return NSMakePoint(8 + dx, 22 + dy);
	}

	return NSMakePoint(0, 0);
}

/*
** Should return an NSSize containing the size of a part of the interface (identified by elementID)
*/
- (NSSize)sizeWithID:(FSPluginElement)elementID
{
	switch (elementID)
	{
		case kElementControler:
			return [[pics objectForKey:[NSNumber numberWithInt:kImagePlayOn]] size];
		
		case kElementPopup:
			return [[pics objectForKey:[NSNumber numberWithInt:kImagePopupOn]] size];
		
		case kElementVolume:
			return [[pics objectForKey:[NSNumber numberWithInt:kImageVolumeOn]] size];
			
		case kElementBack:
			return [[pics objectForKey:[NSNumber numberWithInt:kImageBackPlayPanel]] size];
	
		case kElementText:
			return NSMakeSize(144, 12);
			
		case kElementPercent:
			return NSMakeSize(30, 12);
	}

	return NSMakeSize(0, 0);
}

/*
** Should return an NSDictionary containing the attributes for a text element of the interface (identified by styleID).
*/
- (NSDictionary*)styleWithID:(FSPluginStyle)styleID
{
	if (styleID == kStyleText)
	{
		return [NSDictionary dictionaryWithObjectsAndKeys:	[NSFont fontWithName:@"Papyrus" size:12], NSFontAttributeName,
															[NSColor colorWithDeviceRed:44.0/255.0 green:96.0/255.0 blue:166.0/255.0 alpha:0.7], NSForegroundColorAttributeName,
															nil
				];
	}
	else if (styleID == kStylePercent)
	{
		return [NSDictionary dictionaryWithObjectsAndKeys:	[NSFont fontWithName:@"Papyrus" size:10], NSFontAttributeName,
															[NSColor colorWithDeviceRed:142.0/255.0 green:71.0/255.0 blue:71.0/255.0 alpha:1.0], NSForegroundColorAttributeName,
															nil
				];
	}
	
	return nil;
}

/*
** Allow to hide or show a prefix in the info area
*/
- (BOOL)hiddenPrefix:(FSPluginPrefix)prefixID
{
	return NO;
}

/*
** Allow to know if FStream is recording something (and so adapt the interface)
** This function if called before a call to getImage to draw the changed interface
*/
- (void)setRecording:(BOOL)recording
{

}


/*
** Allow to know the FStream buffer filling state
*/
- (void)setBufferPercent:(int)p100
{

}


/*
** Allow to know the actual showed panel.
** Usefull to change the position of the "display" position by example
*/
- (void)setPanel:(FSPluginPanel)panelID
{

}

/*
** Should return YES if "point" is in the action area of the designated element (identified by elementID), NO else
*/
- (BOOL)mouseOn:(FSPluginElement)elementID withPosition:(NSPoint)point
{
	NSRect r;
	
	r.size = [self sizeWithID:elementID];
	r.origin = [self positionWithID:elementID];
	
	return NSPointInRect(point, r);
}

/*
** A loop call if you want to animate your interface.
** - runnerActionID say the king of event trigger a "runner" action (by example kRunnerLoading,
**   it's the controller who call this function to draw a progressive wave)
** - elementID say the element of interface who trigger the "runner" action (for the previous example,
**   the value is kElementControler)
*/
- (BOOL)runner:(FSPluginRunnerAction)runnerActionID forElement:(FSPluginElement)elementID
{
	if (runnerActionID == kRunnerLoading && elementID == kElementControler)
	{
		anim++;
		
		if (anim >= 2)
		{
			anim = 0;
			animStat = !animStat;
			
			return YES;
		}
	}

	return NO;
}

@end
